@@ -2,8 +2,8 @@ package Cairo::Install::Files;
 
 $self = {
           'deps' => [],
-          'inc' => '-I. -Ibuild -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/uuid  -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/libpng16 -I/usr/include/uuid ',
-          'libs' => '-l:libcairo.dll.a  -l:libcairo.dll.a -lfreetype ',
+          'inc' => '-I. -Ibuild -I/usr/include/cairo -I/usr/include/freetype2 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/libpng16 -I/usr/include/cairo -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/freetype2 -I/usr/include/pixman-1 -I/usr/include/uuid -I/usr/include/libpng16',
+          'libs' => '-l:libcairo.dll.a -l:libcairo.dll.a -lfreetype',
           'typemaps' => [
                           'cairo-perl-auto.typemap',
                           'cairo-perl.typemap'
@@ -27,11 +27,6 @@ $inc = $self->{inc};
 
 	sub Inline {
 		my ($class, $lang) = @_;
-		if ($lang ne 'C') {
-			warn "Warning: Inline hints not available for $lang language
-";
-			return;
-		}
 		+{ map { (uc($_) => $self->{$_}) } qw(inc libs typemaps) };
 	}
 
